@@ -60,6 +60,58 @@ class Agent(AbstractModel):
         
 
 
+class AuthFailMessage(AbstractModel):
+    """授权出错信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ProxyOrganizationOpenId: 合作企业Id
+        :type ProxyOrganizationOpenId: str
+        :param Message: 出错信息
+        :type Message: str
+        """
+        self.ProxyOrganizationOpenId = None
+        self.Message = None
+
+
+    def _deserialize(self, params):
+        self.ProxyOrganizationOpenId = params.get("ProxyOrganizationOpenId")
+        self.Message = params.get("Message")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CcInfo(AbstractModel):
+    """抄送信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Mobile: 被抄送人手机号
+        :type Mobile: str
+        """
+        self.Mobile = None
+
+
+    def _deserialize(self, params):
+        self.Mobile = params.get("Mobile")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Component(AbstractModel):
     """此结构体 (Component) 用于描述控件属性。
 
@@ -397,6 +449,77 @@ class CreateSignUrlsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeFlowDetailInfoRequest(AbstractModel):
+    """DescribeFlowDetailInfo请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Agent: 应用信息
+        :type Agent: :class:`tencentcloud.essbasic.v20210526.models.Agent`
+        :param FlowIds: 合同(流程)编号数组
+        :type FlowIds: list of str
+        :param Operator: 操作者的信息
+        :type Operator: :class:`tencentcloud.essbasic.v20210526.models.UserInfo`
+        """
+        self.Agent = None
+        self.FlowIds = None
+        self.Operator = None
+
+
+    def _deserialize(self, params):
+        if params.get("Agent") is not None:
+            self.Agent = Agent()
+            self.Agent._deserialize(params.get("Agent"))
+        self.FlowIds = params.get("FlowIds")
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeFlowDetailInfoResponse(AbstractModel):
+    """DescribeFlowDetailInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ApplicationId: 渠道侧应用号Id
+        :type ApplicationId: str
+        :param ProxyOrganizationOpenId: 渠道侧企业第三方Id
+        :type ProxyOrganizationOpenId: str
+        :param FlowInfo: 合同(流程)的具体详细描述信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FlowInfo: list of FlowDetailInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ApplicationId = None
+        self.ProxyOrganizationOpenId = None
+        self.FlowInfo = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.ApplicationId = params.get("ApplicationId")
+        self.ProxyOrganizationOpenId = params.get("ProxyOrganizationOpenId")
+        if params.get("FlowInfo") is not None:
+            self.FlowInfo = []
+            for item in params.get("FlowInfo"):
+                obj = FlowDetailInfo()
+                obj._deserialize(item)
+                self.FlowInfo.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeResourceUrlsByFlowsRequest(AbstractModel):
     """DescribeResourceUrlsByFlows请求参数结构体
 
@@ -475,7 +598,7 @@ class DescribeTemplatesRequest(AbstractModel):
         :type Agent: :class:`tencentcloud.essbasic.v20210526.models.Agent`
         :param Operator: 操作者的信息
         :type Operator: :class:`tencentcloud.essbasic.v20210526.models.UserInfo`
-        :param TemplateId: 模版唯一标识
+        :param TemplateId: 模板唯一标识
         :type TemplateId: str
         """
         self.Agent = None
@@ -612,6 +735,103 @@ class DescribeUsageResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DownloadFlowInfo(AbstractModel):
+    """合同（流程）下载信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param FileName: 文件夹名称
+        :type FileName: str
+        :param FlowIdList: 合同（流程）的标识数组
+        :type FlowIdList: list of str
+        """
+        self.FileName = None
+        self.FlowIdList = None
+
+
+    def _deserialize(self, params):
+        self.FileName = params.get("FileName")
+        self.FlowIdList = params.get("FlowIdList")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class FlowApproverDetail(AbstractModel):
+    """签署人的流程信息明细
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ReceiptId: 模板配置时候的签署人id,与控件绑定
+        :type ReceiptId: str
+        :param ProxyOrganizationOpenId: 渠道侧企业的第三方id
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ProxyOrganizationOpenId: str
+        :param ProxyOperatorOpenId: 渠道侧企业操作人的第三方id
+        :type ProxyOperatorOpenId: str
+        :param ProxyOrganizationName: 渠道侧企业名称
+        :type ProxyOrganizationName: str
+        :param Mobile: 签署人手机号
+        :type Mobile: str
+        :param SignOrder: 签署人签署顺序
+        :type SignOrder: int
+        :param ApproveName: 签署人姓名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ApproveName: str
+        :param ApproveStatus: 当前签署人的状态
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ApproveStatus: str
+        :param ApproveMessage: 签署人信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ApproveMessage: str
+        :param ApproveTime: 签署人签署时间
+        :type ApproveTime: int
+        :param ApproveType: 参与者类型 (ORGANIZATION企业/PERSON个人)
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ApproveType: str
+        """
+        self.ReceiptId = None
+        self.ProxyOrganizationOpenId = None
+        self.ProxyOperatorOpenId = None
+        self.ProxyOrganizationName = None
+        self.Mobile = None
+        self.SignOrder = None
+        self.ApproveName = None
+        self.ApproveStatus = None
+        self.ApproveMessage = None
+        self.ApproveTime = None
+        self.ApproveType = None
+
+
+    def _deserialize(self, params):
+        self.ReceiptId = params.get("ReceiptId")
+        self.ProxyOrganizationOpenId = params.get("ProxyOrganizationOpenId")
+        self.ProxyOperatorOpenId = params.get("ProxyOperatorOpenId")
+        self.ProxyOrganizationName = params.get("ProxyOrganizationName")
+        self.Mobile = params.get("Mobile")
+        self.SignOrder = params.get("SignOrder")
+        self.ApproveName = params.get("ApproveName")
+        self.ApproveStatus = params.get("ApproveStatus")
+        self.ApproveMessage = params.get("ApproveMessage")
+        self.ApproveTime = params.get("ApproveTime")
+        self.ApproveType = params.get("ApproveType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class FlowApproverInfo(AbstractModel):
     """创建流程签署人入参
 
@@ -621,10 +841,10 @@ class FlowApproverInfo(AbstractModel):
         r"""
         :param Name: 签署人姓名
         :type Name: str
-        :param Mobile: 签署人手机号，脱敏显示
-        :type Mobile: str
         :param IdCardNumber: 经办人身份证号
         :type IdCardNumber: str
+        :param Mobile: 签署人手机号，脱敏显示
+        :type Mobile: str
         :param JumpUrl: 签署完前端跳转的url，暂未使用
         :type JumpUrl: str
         :param Deadline: 签署截止时间
@@ -635,26 +855,107 @@ class FlowApproverInfo(AbstractModel):
         :type ApproverType: str
         :param OpenId: 用户侧第三方id
         :type OpenId: str
+        :param PreReadTime: 合同的强制预览时间：3~300s，未指定则按合同页数计算
+        :type PreReadTime: int
+        :param ComponentLimitType: 个人签署方指定签署控件类型，目前仅支持：OCR_ESIGN(AI智慧手写签名)
+        :type ComponentLimitType: list of str
+        :param RecipientId: 流程签署人在模板中对应的签署人Id；在非单方签署、以及非B2C签署的场景下必传，用于指定当前签署方在流程中的位置；
+        :type RecipientId: str
+        :param OrganizationName: 同一渠道下其他合作企业OpenId，签署人为非发起方企业员工场景下必传；
+        :type OrganizationName: str
+        :param OrganizationOpenId: 同一渠道下其他合作企业OpenId，签署人为非发起方企业员工场景下必传；
+        :type OrganizationOpenId: str
         """
         self.Name = None
-        self.Mobile = None
         self.IdCardNumber = None
+        self.Mobile = None
         self.JumpUrl = None
         self.Deadline = None
         self.CallbackUrl = None
         self.ApproverType = None
         self.OpenId = None
+        self.PreReadTime = None
+        self.ComponentLimitType = None
+        self.RecipientId = None
+        self.OrganizationName = None
+        self.OrganizationOpenId = None
 
 
     def _deserialize(self, params):
         self.Name = params.get("Name")
-        self.Mobile = params.get("Mobile")
         self.IdCardNumber = params.get("IdCardNumber")
+        self.Mobile = params.get("Mobile")
         self.JumpUrl = params.get("JumpUrl")
         self.Deadline = params.get("Deadline")
         self.CallbackUrl = params.get("CallbackUrl")
         self.ApproverType = params.get("ApproverType")
         self.OpenId = params.get("OpenId")
+        self.PreReadTime = params.get("PreReadTime")
+        self.ComponentLimitType = params.get("ComponentLimitType")
+        self.RecipientId = params.get("RecipientId")
+        self.OrganizationName = params.get("OrganizationName")
+        self.OrganizationOpenId = params.get("OrganizationOpenId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class FlowDetailInfo(AbstractModel):
+    """此结构体(FlowDetailInfo)描述的是合同(流程)的详细信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param FlowId: 合同(流程)的Id
+        :type FlowId: str
+        :param FlowName: 合同(流程)的名字
+        :type FlowName: str
+        :param FlowType: 合同(流程)的类型
+        :type FlowType: str
+        :param FlowStatus: 合同(流程)的状态
+        :type FlowStatus: str
+        :param FlowMessage: 合同(流程)的信息
+        :type FlowMessage: str
+        :param CreateOn: 合同(流程)的创建时间戳
+        :type CreateOn: int
+        :param DeadLine: 合同(流程)的签署截止时间戳
+        :type DeadLine: int
+        :param CustomData: 用户自定义数据
+        :type CustomData: str
+        :param FlowApproverInfos: 合同(流程)的签署人数组
+        :type FlowApproverInfos: list of FlowApproverDetail
+        """
+        self.FlowId = None
+        self.FlowName = None
+        self.FlowType = None
+        self.FlowStatus = None
+        self.FlowMessage = None
+        self.CreateOn = None
+        self.DeadLine = None
+        self.CustomData = None
+        self.FlowApproverInfos = None
+
+
+    def _deserialize(self, params):
+        self.FlowId = params.get("FlowId")
+        self.FlowName = params.get("FlowName")
+        self.FlowType = params.get("FlowType")
+        self.FlowStatus = params.get("FlowStatus")
+        self.FlowMessage = params.get("FlowMessage")
+        self.CreateOn = params.get("CreateOn")
+        self.DeadLine = params.get("DeadLine")
+        self.CustomData = params.get("CustomData")
+        if params.get("FlowApproverInfos") is not None:
+            self.FlowApproverInfos = []
+            for item in params.get("FlowApproverInfos"):
+                obj = FlowApproverDetail()
+                obj._deserialize(item)
+                self.FlowApproverInfos.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -693,6 +994,8 @@ class FlowInfo(AbstractModel):
         :type FlowDescription: str
         :param CustomerData: 渠道的业务信息，限制1024字符
         :type CustomerData: str
+        :param CcInfos: 被抄送人的信息列表，抄送功能暂不开放
+        :type CcInfos: list of CcInfo
         """
         self.FlowName = None
         self.Deadline = None
@@ -703,6 +1006,7 @@ class FlowInfo(AbstractModel):
         self.FormFields = None
         self.FlowDescription = None
         self.CustomerData = None
+        self.CcInfos = None
 
 
     def _deserialize(self, params):
@@ -725,6 +1029,12 @@ class FlowInfo(AbstractModel):
                 self.FormFields.append(obj)
         self.FlowDescription = params.get("FlowDescription")
         self.CustomerData = params.get("CustomerData")
+        if params.get("CcInfos") is not None:
+            self.CcInfos = []
+            for item in params.get("CcInfos"):
+                obj = CcInfo()
+                obj._deserialize(item)
+                self.CcInfos.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -803,6 +1113,169 @@ class FormField(AbstractModel):
         
 
 
+class GetDownloadFlowUrlRequest(AbstractModel):
+    """GetDownloadFlowUrl请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Agent: 应用信息
+此接口Agent.ProxyOrganizationOpenId 和 Agent. ProxyOperator.OpenId 必填
+        :type Agent: :class:`tencentcloud.essbasic.v20210526.models.Agent`
+        :param Operator: 操作者的信息
+        :type Operator: :class:`tencentcloud.essbasic.v20210526.models.UserInfo`
+        :param DownLoadFlows: 文件夹数组，合同（流程）总数不能超过50个，一个文件夹下，不能超过20个合同（流程），
+        :type DownLoadFlows: list of DownloadFlowInfo
+        """
+        self.Agent = None
+        self.Operator = None
+        self.DownLoadFlows = None
+
+
+    def _deserialize(self, params):
+        if params.get("Agent") is not None:
+            self.Agent = Agent()
+            self.Agent._deserialize(params.get("Agent"))
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
+        if params.get("DownLoadFlows") is not None:
+            self.DownLoadFlows = []
+            for item in params.get("DownLoadFlows"):
+                obj = DownloadFlowInfo()
+                obj._deserialize(item)
+                self.DownLoadFlows.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class GetDownloadFlowUrlResponse(AbstractModel):
+    """GetDownloadFlowUrl返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param DownLoadUrl: 进入合同（流程）下载确认页面链接
+        :type DownLoadUrl: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.DownLoadUrl = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.DownLoadUrl = params.get("DownLoadUrl")
+        self.RequestId = params.get("RequestId")
+
+
+class OperateChannelTemplateRequest(AbstractModel):
+    """OperateChannelTemplate请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Agent: 应用信息
+        :type Agent: :class:`tencentcloud.essbasic.v20210526.models.Agent`
+        :param TemplateId: 渠道方模板库模板唯一标识
+        :type TemplateId: str
+        :param OperateType: 操作类型，查询:"SELECT"，删除:"DELETE"，更新:"UPDATE"
+        :type OperateType: str
+        :param Operator: 操作者的信息
+        :type Operator: :class:`tencentcloud.essbasic.v20210526.models.UserInfo`
+        :param AuthTag: 模板可见性, 全部可见-"all", 部分可见-"part"
+        :type AuthTag: str
+        :param ProxyOrganizationOpenIds: 合作企业方第三方机构唯一标识数据，支持多个， 用","进行分隔
+        :type ProxyOrganizationOpenIds: str
+        """
+        self.Agent = None
+        self.TemplateId = None
+        self.OperateType = None
+        self.Operator = None
+        self.AuthTag = None
+        self.ProxyOrganizationOpenIds = None
+
+
+    def _deserialize(self, params):
+        if params.get("Agent") is not None:
+            self.Agent = Agent()
+            self.Agent._deserialize(params.get("Agent"))
+        self.TemplateId = params.get("TemplateId")
+        self.OperateType = params.get("OperateType")
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
+        self.AuthTag = params.get("AuthTag")
+        self.ProxyOrganizationOpenIds = params.get("ProxyOrganizationOpenIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class OperateChannelTemplateResponse(AbstractModel):
+    """OperateChannelTemplate返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param AppId: 腾讯电子签颁发给渠道的应用ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AppId: str
+        :param TemplateId: 渠道方模板库模板唯一标识
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TemplateId: str
+        :param OperateResult: 全部成功-"all-success",部分成功-"part-success", 全部失败-"fail"失败的会在FailMessageList中展示
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OperateResult: str
+        :param AuthTag: 模板可见性, 全部可见-"all", 部分可见-"part"
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AuthTag: str
+        :param ProxyOrganizationOpenIds: 合作企业方第三方机构唯一标识数据
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ProxyOrganizationOpenIds: list of str
+        :param FailMessageList: 操作失败信息数组
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FailMessageList: list of AuthFailMessage
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.AppId = None
+        self.TemplateId = None
+        self.OperateResult = None
+        self.AuthTag = None
+        self.ProxyOrganizationOpenIds = None
+        self.FailMessageList = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.AppId = params.get("AppId")
+        self.TemplateId = params.get("TemplateId")
+        self.OperateResult = params.get("OperateResult")
+        self.AuthTag = params.get("AuthTag")
+        self.ProxyOrganizationOpenIds = params.get("ProxyOrganizationOpenIds")
+        if params.get("FailMessageList") is not None:
+            self.FailMessageList = []
+            for item in params.get("FailMessageList"):
+                obj = AuthFailMessage()
+                obj._deserialize(item)
+                self.FailMessageList.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class PrepareFlowsRequest(AbstractModel):
     """PrepareFlows请求参数结构体
 
@@ -936,6 +1409,8 @@ class Recipient(AbstractModel):
         :type SignType: int
         :param RoutingOrder: 签署顺序：数字越小优先级越高
         :type RoutingOrder: int
+        :param IsPromoter: 是否是发起方
+        :type IsPromoter: bool
         """
         self.RecipientId = None
         self.RecipientType = None
@@ -945,6 +1420,7 @@ class Recipient(AbstractModel):
         self.RequireSign = None
         self.SignType = None
         self.RoutingOrder = None
+        self.IsPromoter = None
 
 
     def _deserialize(self, params):
@@ -956,6 +1432,7 @@ class Recipient(AbstractModel):
         self.RequireSign = params.get("RequireSign")
         self.SignType = params.get("SignType")
         self.RoutingOrder = params.get("RoutingOrder")
+        self.IsPromoter = params.get("IsPromoter")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1278,6 +1755,8 @@ class TemplateInfo(AbstractModel):
         :type TemplateType: int
         :param Recipients: 模板中的流程参与人信息
         :type Recipients: list of Recipient
+        :param IsPromoter: 是否是发起人
+        :type IsPromoter: bool
         """
         self.TemplateId = None
         self.TemplateName = None
@@ -1288,6 +1767,7 @@ class TemplateInfo(AbstractModel):
         self.CreatedOn = None
         self.TemplateType = None
         self.Recipients = None
+        self.IsPromoter = None
 
 
     def _deserialize(self, params):
@@ -1315,6 +1795,7 @@ class TemplateInfo(AbstractModel):
                 obj = Recipient()
                 obj._deserialize(item)
                 self.Recipients.append(obj)
+        self.IsPromoter = params.get("IsPromoter")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
